/*
 * Copyright (c) 2015, Freescale Semiconductor, Inc.
 * Copyright 2016-2017 NXP
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * o Redistributions of source code must retain the above copyright notice, this list
 *   of conditions and the following disclaimer.
 *
 * o Redistributions in binary form must reproduce the above copyright notice, this
 *   list of conditions and the following disclaimer in the documentation and/or
 *   other materials provided with the distribution.
 *
 * o Neither the name of the copyright holder nor the names of its
 *   contributors may be used to endorse or promote products derived from this
 *   software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include <stdbool.h>

#include "board.h"
#include "pin_mux.h"

#include "fsl_debug_console.h"
#include "fsl_gpio.h"
#include "fsl_pint.h"


/*******************************************************************************
 * Definitions
 ******************************************************************************/
#define APP_LED0_GPIO_PORT  0U    /* 红灯亮 */
#define APP_LED0_GPIO_PIN   29U
#define APP_BTN0_GPIO_PORT  0U    /* SW2 */
#define APP_BTN0_GPIO_PIN   31U

/*******************************************************************************
 * Prototypes
 ******************************************************************************/
void App_InitLEDx(void);
void App_InitBTNx(void);

/*******************************************************************************
 * Variables
 ******************************************************************************/

/*******************************************************************************
 * Code
 ******************************************************************************/

/*!
 * @brief Main function
 */
int main(void)
{
    /* 配置引脚复用功能 */
	BOARD_InitBootPins();

    /* 初始化系统时钟 */
    BOARD_BootClockFROHF48M(); /* 主时钟/系统总线时钟为48MHz */
    CLOCK_AttachClk(BOARD_DEBUG_UART_CLK_ATTACH); /* 配置调试串口时钟源为FRO 12M */
    CLOCK_EnableClock(kCLOCK_Gpio0); /* 启用对GPIO0模块寄存器的访问 */

    /* 初始化调试串口 */
    BOARD_InitDebugConsole();

    PRINTF("\r\nGPIO Driver example\r\n");

    App_InitLEDx(); /* 初始化对LED灯的控制 */
    App_InitBTNx(); /* 初始化对按键的控制 */

    while (1)
    {
    	__WFI(); /* 进入低功耗休眠模式 */
    }
}

void App_InitLEDx(void)
{
    gpio_pin_config_t GpioPinConfigStruct;

    GpioPinConfigStruct.pinDirection = kGPIO_DigitalOutput;
    GpioPinConfigStruct.outputLogic = 1U;
    GPIO_PinInit(GPIO, APP_LED0_GPIO_PORT, APP_LED0_GPIO_PIN, &GpioPinConfigStruct);
}

void App_BTN0_PINT_Callback(pint_pin_int_t pintr, uint32_t pmatch_status);

void App_InitBTNx(void)
{
	gpio_pin_config_t GpioPinConfigStruct;

	GpioPinConfigStruct.pinDirection = kGPIO_DigitalInput;
	GPIO_PinInit(GPIO, APP_BTN0_GPIO_PORT, APP_BTN0_GPIO_PIN, &GpioPinConfigStruct);

    PINT_Init(PINT);
    PINT_EnableCallback(PINT);
    PINT_PinInterruptConfig(PINT, kPINT_PinInt0, kPINT_PinIntEnableBothEdges, App_BTN0_PINT_Callback);
}

void App_BTN0_PINT_Callback(pint_pin_int_t pintr, uint32_t pmatch_status)
{
	uint32_t Btn0LogicValue;

	/* 控制小灯 */
	Btn0LogicValue = GPIO_ReadPinInput(GPIO, APP_BTN0_GPIO_PORT, APP_BTN0_GPIO_PIN);
	if (0U == Btn0LogicValue) /* 按下 */
	{
		GPIO_WritePinOutput(GPIO, APP_LED0_GPIO_PORT, APP_LED0_GPIO_PIN, 0U); /* 亮灯 */
	}
	else if (1U == Btn0LogicValue) /* 弹起 */
	{
		GPIO_WritePinOutput(GPIO, APP_LED0_GPIO_PORT, APP_LED0_GPIO_PIN, 1U); /* 灭灯 */
	}
}
